# DUDraw

Repository for DUDraw, a fork of [stddraw from the Princeton Standard Libraries](https://introcs.cs.princeton.edu/python/code/). 

Released under the [GNU Public License version 3 (GPLv3)](https://www.gnu.org/licenses/gpl-3.0.html)

Original Authors of [StdLib](https://introcs.cs.princeton.edu/java/stdlib/):

    Robert Sedgewick
    Kevin Wayne
 
DUDraw Fork Additions by:

    Joseph Brooksbank
    Ryan Dunagan
    Declan Kahn
    Eddy Rogers
    Andrew Hannum
